Module objects

Module objects 

PDF object types

This module implements the core PDF object types as defined in the PDF specification. PDF documents are built from these basic object types.

Structs

PdfArray
A PDF array
PdfDict
A PDF dictionary
PdfHexString
A PDF hexadecimal string
PdfName
A PDF Name object
PdfRef
A PDF indirect object reference
PdfStream
A PDF stream object
PdfString
A PDF literal string

Enums

PdfNumber
A PDF number (integer or real)
PdfObject
A PDF object that can be any of the basic PDF types

Functions

format_real
Formats a floating-point number for PDF output using ryu for optimal precision.