PdfObject

Enum PdfObject 

pub enum PdfObject {
    Null,
    Bool(bool),
    Integer(i64),
    Real(f64),
    Name(PdfName),
    String(PdfString),
    HexString(PdfHexString),
    Array(PdfArray),
    Dict(PdfDict),
    Stream(PdfStream),
    Reference(PdfRef),
}
A PDF object that can be any of the basic PDF types

Variants



Null

Null object



Bool(bool)

Boolean value



Integer(i64)

Integer number



Real(f64)

Real number



Name(PdfName)

Name object (e.g., /Type)



String(PdfString)

Literal string



HexString(PdfHexString)

Hexadecimal string



Array(PdfArray)

Array of objects



Dict(PdfDict)

Dictionary



Stream(PdfStream)

Stream (dictionary + data)



Reference(PdfRef)

Indirect reference (e.g., 1 0 R)

Implementations

Source

impl PdfObject

pub fn is_null(&self) -> bool

Returns true if this is a null object

pub fn as_bool(&self) -> Option<bool>

Returns the boolean value if this is a Bool, None otherwise

pub fn as_integer(&self) -> Option<i64>

Returns the integer value if this is an Integer, None otherwise

pub fn as_real(&self) -> Option<f64>

Returns the real value if this is a Real or Integer, None otherwise

pub fn as_name(&self) -> Option<&PdfName>

Returns a reference to the Name if this is a Name, None otherwise

pub fn as_string(&self) -> Option<&PdfString>

Returns a reference to the String if this is a String, None otherwise

pub fn as_array(&self) -> Option<&PdfArray>

Returns a reference to the Array if this is an Array, None otherwise

pub fn as_array_mut(&mut self) -> Option<&mut PdfArray>

Returns a mutable reference to the Array if this is an Array, None otherwise

pub fn as_dict(&self) -> Option<&PdfDict>

Returns a reference to the Dict if this is a Dict, None otherwise

pub fn as_dict_mut(&mut self) -> Option<&mut PdfDict>

Returns a mutable reference to the Dict if this is a Dict, None otherwise

pub fn as_stream(&self) -> Option<&PdfStream>

Returns a reference to the Stream if this is a Stream, None otherwise

pub fn as_reference(&self) -> Option<PdfRef>

Returns the Reference if this is a Reference, None otherwise

pub fn type_name(&self) -> &'static str

Returns the type name of this object