pub struct PdfArray(/* private fields */);Expand description
A PDF array
Arrays can contain any mix of PDF objects and can be nested.
Implementations
Sourceimpl PdfArray
impl PdfArray
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an array with the given capacity
Sourcepub fn push<T: Into<PdfObject>>(&mut self, object: T)
pub fn push<T: Into<PdfObject>>(&mut self, object: T)
Pushes an object onto the end of the array
Sourcepub fn get(&self, index: usize) -> Option<&PdfObject>
pub fn get(&self, index: usize) -> Option<&PdfObject>
Gets a reference to the object at the given index
Sourcepub fn get_mut(&mut self, index: usize) -> Option<&mut PdfObject>
pub fn get_mut(&mut self, index: usize) -> Option<&mut PdfObject>
Gets a mutable reference to the object at the given index
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = &mut PdfObject>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut PdfObject>
Returns a mutable iterator over the objects
Sourcepub fn get_integer(&self, index: usize) -> Option<i64>
pub fn get_integer(&self, index: usize) -> Option<i64>
Gets an integer at the given index
Sourcepub fn get_reference(&self, index: usize) -> Option<PdfRef>
pub fn get_reference(&self, index: usize) -> Option<PdfRef>
Gets a reference at the given index